# spotter

*Approximate forward models of fluxes and spectra time-series of non-uniform stars.*

---


*spotter* uses the [HEALPix](https://healpix.sourceforge.io/) subdivision scheme and is powered by the high-performance numerical package [JAX](https://jax.readthedocs.io/en/latest/notebooks/quickstart.html), enabling its use on GPUs.

```{toctree}
:maxdepth: 1
:caption: Get started

installation
notebooks/introduction
notebooks/precision.ipynb
```

```{toctree}
:maxdepth: 1
:caption: Tutorials

notebooks/surface_gp
notebooks/ensemble
notebooks/spectral
notebooks/multiband
notebooks/spot_crossing
notebooks/rv


```

```{toctree}
:maxdepth: 1
:caption: Reference

notebooks/principle.ipynb

```